@@ -199,7 +199,7 @@ class TvRenamr(object):
             TvRage
         ]
         [libraries.insert(0, libraries.pop(libraries.index(lib)))
-        for lib in libraries if lib.__name__.lower() == library]
+            for lib in libraries if lib.__name__.lower() == library]
 
         # TODO: Make this bit not suck.
         if canonical:
@@ -263,7 +263,9 @@ class TvRenamr(object):
 
         """
         if rename_dir is None:
-            rename_dir = self.config.get(_file.show_name, 'renamed', self.working_dir)
+            rename_dir = self.config.get(_file.show_name, 'renamed')
+        if rename_dir is False:
+            rename_dir = self.working_dir
 
         if organise is None:
             organise = self.config.get(_file.show_name, 'organise')
